@@ -5,7 +5,7 @@ import time
 import click
 import pkg_resources
 from livereload import Server, shell
-from . import Generator
+from . import Generator, lib
 from .ssg import PAGE_FORMAT
 from .__about__ import *
 
@@ -137,29 +137,38 @@ def version():
     footer()
 
 
-@cli.command("create")
-@click.argument("sitename")
-def create_site(sitename):
-    """Create a new site directory and init SSG"""
-    title('Create new site')
+@cli.command("generate")
+@click.option("--site", default=None)
+def generate(site=None):
+    """Generate a new site directory from --site or base_dir in the ssg.yml"""
+    title('Generate new site')
     ssg_conf = os.path.join(CWD, "ssg.yml")
-    if os.path.isfile(ssg_conf):
-        error_exit("Can't create new site in a directory that contain 'ssg.yml'")
-    
-    sitepath = os.path.join(CWD, sitename)
-    if os.path.isdir(sitepath):
-        error_exit("Site directory '%s' exists already!" % sitename)
-    else:
-        info("Creating site: %s..." % sitename)
+
+    if not site and os.path.isfile(ssg_conf):
+        if conf := lib.load_conf(ssg_conf):
+            if base_dir := conf.get("base_dir"):
+                site = base_dir
+            else:
+                error_exit("SSG already initialized in '%s'. Or delete 'ssg.yml' if a mistake " % CWD)
+    if not site:
+        error_exit("site or base_dir not set. Use 'ssg init' to initialize in the current directory")
+
+    sitepath = os.path.join(CWD, site)
+    if not os.path.isdir(sitepath):
+        info("Generating site: %s..." % site)
         os.makedirs(sitepath)
         copy_resource("skel/", sitepath)
         stamp_ssg_current_version(sitepath)
         info("Site created successfully!")
-        info("CD into '%s' and run 'ssg serve' to view the site" % sitename)
+        info("Update the [base_dir:'%s'] in ssg.yml and run 'ssg serve' to view the site" % site)
+    else:
+        error_exit("Site directory '%s' exists already!" % site)
 
     done()
 
 
+
+
 @cli.command("init")
 def init():
     """Initialize SSG in the current directory """
@@ -218,6 +227,7 @@ def create_page(pagenames):
     done()
 
 
+
 @cli.command("build")
 @click.option("-i", "--info", is_flag=True)
 @click.option("--env", default=None)
@@ -233,7 +243,7 @@ def build(info, env):
 
     done()
 
-@cli.command()
+@cli.command("serve")
 @click.option("-p", "--port", default=None)
 @click.option("--no-livereload", default=None)
 @click.option("--open-url", default=None)
@@ -268,7 +278,7 @@ def serve(port, no_livereload, open_url, env):
     server = Server()
     if no_livereload is False:
         server.watch(K.static_dir + "/", build_static)
-        for c in [K.pages_dir, K.templates_dir, K.content_dir, K.data_dir]:
+        for c in [K.pages_dir, K.templates_dir, K.data_dir]:
             server.watch(c + "/", build_pages)
 
     server.serve(open_url_delay=open_url, port=str(port), root=K.build_dir)
@@ -281,9 +291,9 @@ def clean():
     Generator(CWD).clean_build_dir()
     done()
 
-@cli.command("macros")
+#@cli.command("macros")
 def macros():
-    """Clean the build dir """
+    """ List all macros """
     title("SSG macros")
     K = Generator(CWD)
     macros = K.ssg_macros
