@@ -145,7 +145,7 @@ def load_yaml_file(file):
 
 def load_json_file(file):
     with open(file) as f:
-        if d := json.loads(f.read()):#json_loads(f.read()):
+        if d := json.loads(f.read()):
             if isinstance(d, dict):
                 return dictdot(d)
             return d
