@@ -84,6 +84,8 @@ class Generator(object):
             "css": []           # List of all CSS url in the page
         }
     }
+    root_dir = None 
+    base_dir = None
     tpl_env = None
     _templates = {}
     #pages_data__ = {}
@@ -91,20 +93,11 @@ class Generator(object):
     def __init__(self, root_dir, options={}):
         """
 
-        :param root_dir: The application root dir
+        :param root_dir: The application root dir, where ssg.yml exists
         :param options: options to build
         """
 
-        self.root_dir = root_dir
-        self.build_dir = os.path.join(self.root_dir, "build")
-        self.static_dir = os.path.join(self.root_dir, "static")
-        self.content_dir = os.path.join(self.root_dir, "content")
-        self.pages_dir = os.path.join(self.root_dir, "pages")
-        self.templates_dir = os.path.join(self.root_dir, "templates")
-        self.data_dir = os.path.join(self.root_dir, "data")
-        self.build_static_dir = os.path.join(self.build_dir, "static")
-        self.build_static_gen_dir = os.path.join(self.build_static_dir, "_gen")
-
+        self.root_dir = self.base_dir = root_dir
         self.config_file = os.path.join(self.root_dir, "ssg.yml")
         self.config = lib.load_conf(self.config_file)
         self.config.setdefault("env", {})
@@ -112,6 +105,27 @@ class Generator(object):
         self.config.setdefault("build", {})
         self.config.setdefault("globals", {})
         self.config.setdefault("assets_bundles", {})
+
+        # * base_dir
+        # base_dir: relative to the ssg.yml, the dir containing the artifact
+        if base_dir := self.config.get("base_dir"):
+            self.base_dir = os.path.join(self.root_dir, base_dir)
+
+        # * build_dir
+        # build_dir: relative to the ssg.yml, the dir that contains the output
+        if build_dir := self.config.get("build_dir"):
+            self.build_dir = os.path.join(self.root_dir, build_dir)
+        else:
+            self.build_dir = os.path.join(self.base_dir, "_build")
+
+        self.public_dir = os.path.join(self.base_dir, "public")
+        self.static_dir = os.path.join(self.base_dir, "static")
+        self.pages_dir = os.path.join(self.base_dir, "pages")
+        self.templates_dir = os.path.join(self.base_dir, "templates")
+        self.data_dir = os.path.join(self.base_dir, "data")
+        self.build_static_dir = os.path.join(self.build_dir, "_static")
+        self.build_static_gen_dir = os.path.join(self.build_static_dir, "_gen")
+
         self.layout = self.config.get("globals.layout", DEFAULT_LAYOUT)
 
         build_type = options.get("build", "build")
@@ -130,7 +144,7 @@ class Generator(object):
 
         self.site_env = site_env
         self.site_config.setdefault("base_url", "/")
-        self.site_config.setdefault("static_url", "/static")
+        self.site_config.setdefault("static_url", "/_static")
         self.base_url = self.site_config.get("base_url")
         self.static_url = self.site_config.get("static_url")
         self._context_root = "./"
@@ -140,16 +154,17 @@ class Generator(object):
         self.print_info = False
 
         self._init_jinja({
-            "get_page": self._get_page,
-            "get_page_url": self._get_page_url,
-            "get_static_url": self._get_static_url,
-            "get_resources": self._get_resouces,
-            "get_static_bundle": self._get_page_static_bundle_url,
+            "get_page_context": self._get_page,
+            "get_url_for": self._get_page_url,
+            "get_static_url_for": self._get_static_url,
+            "get_static_bundle_url_for": self._get_page_static_bundle_url,
+            "get_public_url_for": None,
+            "get_resources": self._get_resources,
             "get_site": self._get_site,
             "format_date": lambda dt, format="MM/DD/YYYY h:mm a": arrow.get(dt).format(format),
-            "current_date": lambda: arrow.now(),
+            "get_current_date": lambda: arrow.now(),
             "site": self.site_config,
-            "__info": self._load_info(),
+            "__info__": self._load_info()
         })
  
     def _load_info(self):
@@ -168,7 +183,6 @@ class Generator(object):
 
 
         loader = jinja2.ChoiceLoader([
-            jinja2.PrefixLoader({'content':jinja2.FileSystemLoader(self.content_dir)}),
             jinja2.FileSystemLoader(self.templates_dir)
         ])
 
@@ -185,7 +199,7 @@ class Generator(object):
         self.tpl_env.add_extension('jinja2.ext.do')
         self.tpl_env.globals.update(global_context)
 
-    def _get_resouces(self, path):
+    def _get_resources(self, path):
         """
         Get the data from /data dir
 
@@ -271,7 +285,16 @@ class Generator(object):
 
     def _get_static_url(self, url):
         """Returns the static url """
-        if url.startswith("//") or url.startswith("http"):
+        if url.startswith("//") or bool(re.match('https?://', url)):
+            return url
+        url = self.static_url.rstrip("/") + "/" + url.lstrip("/")
+        if len(self._context_root.split("..")) > 1:
+            self._context_root.rstrip("/") + url
+        return url
+
+    def _get_public_url(self, url):
+        """Returns the static url """
+        if url.startswith("//") or bool(re.match('https?://', url)):
             return url
         url = self.static_url.rstrip("/") + "/" + url.lstrip("/")
         if len(self._context_root.split("..")) > 1:
@@ -321,7 +344,7 @@ class Generator(object):
                         m = lib.load_yaml_file if fname.endswith(".yml") else lib.load_json_file
                         data[name] = m(fname)
 
-        # load the data from config.remote_resources
+        # load the data from config.datasources
         """
         format:
             name:str
@@ -337,8 +360,8 @@ class Generator(object):
             disabled:bool - to disabled the request
         """
 
-        if remote_resources := self.config.get("remote_resources"):
-            for d in remote_resources:
+        if datasources := self.config.get("datasources"):
+            for d in datasources:
                 if name := d.get("name"):
                     if not d.get("request"):
                         raise Exception("BUILD ERROR: remote resource '%s' missing request object" % name)
@@ -399,8 +422,17 @@ class Generator(object):
 
                     Properties:
                         - resources: somename_from_dataDir_or_remoteResources
-                        - type: single|paged
+                        - type: single|list
 
+                    # single 
+                    To display a single entry. 
+                    The page reference will be $pagename:$page_id or a $permalink
+
+                    # list
+                    To create a list of item. 
+                    Optionally, individual pages can exist for more details
+                    href = $pagename:page_num or $permalink
+                    
 
                     Example: 
                     Having the data `data/articles.json` -> [{title, slug, content, ...},...]
@@ -428,8 +460,9 @@ class Generator(object):
                     if not isinstance(rdata, list):
                         raise Exception("BUILD ERROR: Generator data type must be of List|Array for '%s'" % _resources_name)
 
-                    # SINGLE
+                    # ::SINGLE
                     # generates single pages off of the data
+
                     if not _gen_type or _gen_type.upper() == "SINGLE":
                         
                         for data in rdata:
@@ -469,10 +502,19 @@ class Generator(object):
                                 "layout": mdata.get("layout") or self.layout
                             })
    
-                    # LIST
+                    # ::LIST
+                    # To create a paginated listing page similar to a blog page. 
+                    # Each page will contain a chunk list of the data
+                    # This can be use to show a list.
+                    # NOTE: While a list contain the list of the content, 
+                    # it's can be necessary to create another Generator to show single/indivual page.
+                    # This way you can link to them.
+                    #
+                    #
                     # create a paginated with [Prev] [Next]
                     # Each page will contain a chunk of the data
-                    # will split the content into multi pages
+                    # will split the content into multi pages.
+                    # Also a index/default page will be created for the first page
                     if _gen_type.upper() == "LIST":
                         raise NotImplementedError()
 
@@ -520,6 +562,7 @@ class Generator(object):
                             has_next_page = next_page < total_pages
 
                             pagination = {
+                                "items_per_page": per_page,
                                 "current_page": current_page,
                                 "prev_page": prev_page,
                                 "has_prev_page": has_prev_page,
@@ -622,6 +665,11 @@ class Generator(object):
             print_info('copying static dir to build folder...')
         copy_tree(self.static_dir, self.build_static_dir)
 
+        if os.path.exists(self.public_dir):
+            print_info('copying public dir content to build folder...')
+            copy_tree(self.public_dir, self.build_dir)
+
+
     def build_pages(self) -> int:
         """Iterate over the pages_dir and build the pages """
         src_files = []
@@ -697,7 +745,6 @@ class Generator(object):
         if "url" not in _context["page"]:
             _context["page"]["url"] = "/" + \
                 filepath.lstrip("/").replace("index.html", "")
-            print("NOT HERE", filepath, _context["page"]["url"])
         self._reset_page_context_assets(_context)
 
         #! redirect
@@ -766,18 +813,18 @@ class Generator(object):
             With bundle enabled, you can instead put the bundle on the page instead of individual files
 
             = Bundle
-                <link rel="stylesheet" type="text/css" href="{{ get_static_bundle(page, 'page_css_bundle') }}">
+                <link rel="stylesheet" type="text/css" href="{{ get_static_bundle_url_for(page, 'page_css_bundle') }}">
 
-                <script type="text/javascript" src="{{ get_static_bundle(page, 'page_js_bundle') }}"></script>
+                <script type="text/javascript" src="{{ get_static_bundle_url_for(page, 'page_js_bundle') }}"></script>
 
             = No bundle
 
                 {% for file in page.__assets.js %}
-                    <script type="text/javascript" src="{{ get_static_url(file) }}"></script>
+                    <script type="text/javascript" src="{{ get_static_url_for(file) }}"></script>
                 {% endfor %}
 
                 {% for file in page.__assets.css %}
-                    <link rel="stylesheet" type="text/css" href="{{ get_static_url(file) }}">
+                    <link rel="stylesheet" type="text/css" href="{{ get_static_url_for(file) }}">
                 {% endfor %}
 
             """
